@@ -43,7 +43,7 @@ It doesn't parse the current MAGMAv0.2 files!
 Use it only, if you want to take a peek at what the updated specification will bring. 
 
 
-It depends on U{pyyaml <http://pyyaml.org/>}. 
+It depends on U{pyyaml <http://pyyaml.org/>}, tagpy and IPy. 
 
 An example magma file is I{example-0.4.magma}. 
 
@@ -57,11 +57,11 @@ Usage of this module
 ====================
 
     >>> # from magma import *
-    >>> mag = open_file("example-0.4.magma")
+    >>> magma = open_file("example-0.4.magma")
 
 or 
 
-    >>> mag = Magma(input_files=["input_file.txt", "input_file2.txt"])    
+    >>> magma = create_from_input_files(["input_file.txt", "input_file2.txt"])
 
 
 API / usage
@@ -70,10 +70,10 @@ API / usage
 B{Creating magma lists from input files}
     
 Create a list from input files. 
-    >>> mag = create_from_input_files(["input_file.txt"])
+    >>> magma = create_from_input_files(["input_file.txt"])
     
 Output the list, showing the empty entries, which could be filled with data. 
-    >>> print mag
+    >>> print magma
     #MAGMAv0.4
     files:
     - filename: input_file.txt
@@ -89,24 +89,24 @@ Output the list, showing the empty entries, which could be filled with data.
     <BLANKLINE>
     
 And save it to a file with the empty entries cleaned away. 
-    >>> mag.save(path="example.magma")
+    >>> magma.save(path="example.magma")
 
 
 Or just return a list of its files as MagmaFiles. 
-    >>> files = mag.files
+    >>> files = magma.files
     
 Or output all magnet links inside the magma list. 
-   >>> print mag.magnets
+   >>> print magma.magnets
    ['magnet:?xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt']
   
   
 B{Reading from magma lists}
    
 Readout the data from a file. 
-   >>> mag = open_file("example.magma")
+   >>> magma = open_file("example.magma")
    
 Now get the files inside the list. 
-   >>> files = mag.files
+   >>> files = magma.files
    >>> for i in files: print i
    input_file.txt 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
    
@@ -125,21 +125,21 @@ Or output all its (meta-) data.
    
 
 Output all magnet links inside the magma list. 
-   >>> print mag.magnets
+   >>> print magma.magnets
    ['magnet:?xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt']
 
 Load a Magma object from a string containing Magma data via magma.load(). 
 As test, load a minimal Magma file, containing nothing but the header.
-   >>> mag = load("#MAGMAv0.4")
+   >>> magma = load("#MAGMAv0.4")
    
 And cry out, if the string doesn't begin with the Magma header (isn't Magma data!). 
-   >>> mag = load("a:b")
+   >>> magma = load("a:b")
    Traceback (most recent call last):
    ...
    AssertionError: Doesn't begin with Magma v0.4 header #MAGMAv0.4
 
 Also dump yaml data via magma.dump()
-   >>> print dump(mag)
+   >>> print dump(magma)
    #MAGMAv0.4
    {}
    <BLANKLINE>
@@ -148,7 +148,7 @@ Also dump yaml data via magma.dump()
    <BLANKLINE>
 
 Or just print the Magma data. 
-   >>> print mag
+   >>> print magma
    #MAGMAv0.4
    {}
    <BLANKLINE>
@@ -181,7 +181,7 @@ __copyright__ = 'Copyright (C) 2008 Arne Babenhauserheide'
 __date__ = '2008-05-09'
 __licence__ = 'GPL-3 or later'
 __program__ = 'MAGnet MAnifest Management'
-__version__ = '0.3.7'
+__version__ = '0.3.8'
 
 # The dependencies of the _init__ only. 
 __depends__ = ''
@@ -228,8 +228,8 @@ from magma_list import Magma
 def open_file(filepath):
     """Open a file as Magma list and produce the corresponding Python object.
     
-    @param yaml_data: Data read from a yaml file. 
-    @type yaml_data: String
+    @param filepath: The path to a Magma file.
+    @type filepath: String
     @return: A Magma Object. 
     """
     return Magma(magma_file=filepath)
