@@ -168,7 +168,7 @@ class Magma(object):
         return self.readout_yaml(file_data)
         
     def files(self):
-        """Get the files from the magma data
+        """Get the files from the magma data.
         
         @return: A list of all MagmaFile objects from the Magma.
         """
